**************************************************************************************
**** Lois. D. & Arranz Becker, O.: Parental status homogeneity in social networks: ***
**** The role of homophilous tie selection in Germany ********************************
**************************************************************************************

clear all
set maxvar 10000
version 17
* Please adapt to your directory
global datapath "c:\Daten\" 
cd "c:\Daten\"


* Date of interview in W2, total nw-size in W2

use "$datapath\anchor2.dta", clear

egen nwsizet_w2 = anycount(net5p1-net5p30), values(1/21) 

keep id intm inty nwsizet_w2 cohort

replace id = id/1000

save "intdate_w2.dta", replace


***************************************************************************
*** Selection Model: Participation in W4 + Interviewer IDs + Covariates ***
***************************************************************************

use "$datapath\anchor4.dta", clear

keep id 

gen id_w4 = id 

save "w4id.dta", replace

use "$datapath\anchor2.dta", clear

merge 1:1 id using "$datapath\w4id.dta", keep(match master)

recode _merge (3=1) (1=0), gen(res)

recode sex_gen (1=1) (2=0) (-2=.), gen(male)

recode yeduc (-7=.) (0=12), gen (yeduc2)

gen intcontq = intcont*intcont

gen mig = 0 
replace mig = 1 if migstatus == 2 | migstatus == 3

recode res2nd (-7=.)

gen noagree = 0 
replace noagree = 1 if cps1 == 2

recode job7 (-3=0) (-4=.) (-2=.) (-1=.), gen(wtime)

recode nkidsliv (-7=.)

recode relstat (1=1) (6=1) (9=1) (-7=.) (else=0), gen(single) 
recode relstat (2=1) (5=1) (7=1) (-7=.) (else=0), gen(lat)
recode relstat (3=1) (8=1) (-7=.) (else=0), gen(nel) 
recode relstat (4=1) (-7=.) (else=0), gen(marr) 

probit res male i.cohort yeduc2 int7 intcont intcontq gkpol mig res2nd noagree wtime nkidsliv single
predict yhat if e(sample)
ttest yhat, by(res)
* Tjur R² is 0.048

probit res male i.cohort yeduc2 int7 intcont intcontq gkpol mig res2nd noagree wtime nkidsliv single

predict xb, xb

recode xb (.=0.64)

gen lambda = normalden(xb)/normal(xb)

rename intid intid_w2

* Covariates 

recode net5p1 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter1) 
recode net5p2 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter2) 
recode net5p3 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter3) 
recode net5p4 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter4)  
recode net5p5 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter5) 
recode net5p6 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1)(else = 0), gen(filter6) 
recode net5p7 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter7) 
recode net5p8 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter8) 
recode net5p9 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter9) 
recode net5p10 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter10) 
recode net5p11 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter11) 
recode net5p12 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter12) 
recode net5p13 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter13) 
recode net5p14 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter14) 
recode net5p15 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter15) 
recode net5p16 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter16) 
recode net5p17 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter17) 
recode net5p18 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter18) 
recode net5p19 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter19) 
recode net5p20 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter20) 
recode net5p21 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter21) 
recode net5p22 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter22) 
recode net5p23 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter23) 
recode net5p24 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter24) 
recode net5p25 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter25) 
recode net5p26 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter26) 
recode net5p27 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter27) 
recode net5p28 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter28)
recode net5p29 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter29) 
recode net5p30 (2=1) (12=1) (15=1) (17=1) (19=1) (20=1) (21=1) (else = 0), gen(filter30)

egen nwsize_w2_all = anycount(filter1-filter30), values(1)

rename nkids nkids2

recode k1age (0/2=1) (3/7=2) (8/99=3), gen(agek1) 
recode k2age (0/2=1) (3/7=2) (8/99=3), gen(agek2)  
recode k3age (0/2=1) (3/7=2) (8/99=3), gen(agek3) 
recode k4age (0/2=1) (3/7=2) (8/99=3), gen(agek4) 
recode k5age (0/2=1) (3/7=2) (8/99=3), gen(agek5) 
recode k6age (0/2=1) (3/7=2) (8/99=3), gen(agek6) 
recode k7age (0/2=1) (3/7=2) (8/99=3), gen(agek7) 
recode k8age (0/2=1) (3/7=2) (8/99=3), gen(agek8) 
recode k9age (0/2=1) (3/7=2) (8/99=3), gen(agek9) 
recode k10age (0/2=1) (3/7=2) (8/99=3), gen(agek10)

egen child02 = anycount(agek1-agek10), values(1)
egen child37 = anycount(agek1-agek10), values(2)
egen child8p = anycount(agek1-agek10), values(3)

recode child02 (0=0) (1/99=1)
recode child37 (0=0) (1/99=1)
recode child8p (0=0) (1/99=1) 

keep id lambda intid_w2 male age ykage ykagecapi nkids2 child02 child37 child8p pregnant nwsize_w2_all cohort ///
single nel lat marr

replace id = id/1000

save "lambdaid_w2.dta", replace

use "$datapath\anchor4.dta", clear

rename intid intid_w4 

replace id = id/1000

egen nwsizet_w4 = anycount(net5p1-net5p30), values(1/21)

keep id intid_w4 nwsizet_w4

save "intid_w4.dta", replace

use "$datapath\anchor4.dta", clear

replace id = id / 1000

keep id relstat k1age-k10age sex_gen age pregnant infertile k1type-k10type nkids nkidsbio ykage ykagecapi

save "out_anchor4.dta", replace


*******************************************
**** Preparation for Record Linkage, W2 ***
*******************************************

use "$datapath\anchor2.dta", clear

keep id net10p1-net10p30 net11p1-net11p30 net5p1-net5p30 net7p1-net7p30 net12p1-net12p28 net13p1-net13p30 net14p1-net14p28

replace id = id/1000

merge 1:1 id using "$datapath\names2.dta", keep(match master)

drop _merge

rename str_netp1n netpn1
rename str_netp2n netpn2
rename str_netp3n netpn3
rename str_netp4n netpn4
rename str_netp5n netpn5
rename str_netp6n netpn6
rename str_netp7n netpn7
rename str_netp8n netpn8
rename str_netp9n netpn9
rename str_netp10n netpn10
rename str_netp11n netpn11
rename str_netp12n netpn12
rename str_netp13n netpn13
rename str_netp14n netpn14
rename str_netp15n netpn15
rename str_netp16n netpn16
rename str_netp17n netpn17
rename str_netp18n netpn18
rename str_netp19n netpn19
rename str_netp20n netpn20
rename str_netp21n netpn21
rename str_netp22n netpn22
rename str_netp23n netpn23
rename str_netp24n netpn24
rename str_netp25n netpn25
rename str_netp26n netpn26
rename str_netp27n netpn27
rename str_netp28n netpn28
rename str_netp29n netpn29
rename str_netp30n netpn30

gen net12p24 = .
gen net12p27 = .
gen net14p27 = .

drop net5p29 net5p30 net7p30 net10p30 net11p30 net13p30 netpn29 netpn30

reshape long net5p net7p net10p net11p net12p net13p net14p netpn, i(id) j(nwpnr)

* Deletion of abbrevations (for second first names or last names)

split netpn, destring

drop netpn2 netpn3 netpn4

drop if netpn1 =="-3" 
drop if netpn1 =="-6" 
drop if netpn1 == ""
drop if net10p == -3 & net11p == -3

* Cleaning of names

*Aileen*
foreach var of varlist netpn1						{
		replace `var'="Aileen" if `var'=="Ailleen" 
	}

*Alexander*
foreach var of varlist netpn1 	{
		replace `var'="Alexander" if `var'=="Allexander" | `var'=="Alex"
	}

*Alisa*
foreach var of varlist netpn1	{
		replace `var'="Alisa" if `var'=="Alisa-Nina" 
	}

*Amelie*
foreach var of varlist netpn1 	{
		replace `var'="Amelie" if `var'=="Ammelie" | `var'=="Ammely" | `var'=="Amely"
	} 

*Andre*
foreach var of varlist netpn1 	{
		replace `var'="Andre" if `var'=="Andrè" | `var'=="Anré" | `var'=="André" | ///
				`var'=="Andre´" 
	}

*Anja*
foreach var of varlist netpn1	{
		replace `var'="Anja" if `var'=="Ania"
	}

*Annabell*
foreach var of varlist netpn1 	{
		replace `var'="Annabell" if `var'=="Annabel"
	}
	
*Annelie*
foreach var of varlist netpn1 	{
		replace `var'="Annelie" if `var'=="Annelie-Sophie"
	}

*Annett*
foreach var of varlist netpn1 	{
		replace `var'="Annett" if `var'=="Anett" | `var'=="Annek" | `var'=="Anete" | ///
				`var'=="Anette" | `var'=="Annette" | `var'=="Annete"
	}
	
*Annegret*
foreach var of varlist netpn1	{
		replace `var'="Annegret" if `var'=="Anne-Gret"
	}
	
*Annkatrin*
foreach var of varlist netpn1 	{
		replace `var'="Annkatrin" if `var'=="Ann-Katrin" | `var'=="Annkathrin" | ///
				`var'=="Ann-Kathrin"
	}
	
*Astrid"
foreach var of varlist netpn1	{
		replace `var'="Astrid" if `var'=="Astridt"
	}
	
*Bastian"
foreach var of varlist netpn1 	{
		replace `var'="Bastian" if `var'=="Basti"
	}
	
*Benedikt*
foreach var of varlist netpn1	{
		replace `var'="Benedikt" if `var'=="Benedict"
	}
	
*Benjamin*
foreach var of varlist netpn1 	{
		replace `var'="Benjamin" if `var'=="Beniamin" | `var'=="Benni" 
	}

*Bianca*
foreach var of varlist netpn1 	{
		replace `var'="Bianca" if `var'=="Bianka" | `var'=="Bibbi" | `var'=="Bibby"
	}

*Boris*
foreach var of varlist netpn1	{
		replace `var'="Boris" if `var'=="Borris"
	}

*Burak*
foreach var of varlist netpn1 	{
		replace `var'="Burak" if `var'=="Burak-Nazif"
	}
	
*Carla*
foreach var of varlist netpn1 	{
		replace `var'="Carla" if `var'=="Zwilling"
	}
	
*Carmen*
foreach var of varlist netpn1	{
		replace `var'="Carmen" if `var'=="Karmen"
	}

*Catrin*
foreach var of varlist netpn1	{
		replace `var'="Catrin" if `var'=="Cathrin"
	}
	
*Cecilia*
foreach var of varlist netpn1 	{
		replace `var'="Cecilia" if `var'=="Cäcilia"
	}
	
*Cedric*
foreach var of varlist netpn1 {
		replace `var'="Cedric" if `var'=="CéDric"
	}
	
*Celine*
foreach var of varlist netpn1 	{
		replace `var'="Celine" if `var'=="Cèline" | `var'=="Cèlin" | `var'=="Celin" | ///
		        `var'=="CéLine"
	}

*Chanice*
foreach var of varlist netpn1 	{
		replace `var'="Chanice" if `var'=="Charice"
	}

*Christian*
foreach var of varlist netpn1 	{
		replace `var'="Christian" if `var'=="Kristian" | `var'=="Christan"
	}

*Christina*
foreach var of varlist netpn1	{
		replace `var'="Christina" if `var'=="Kristina"
	}

*Christine*
foreach var of varlist netpn1 	{
		replace `var'="Christine" if `var'=="Kristine" | `var'=="Christin" | `var'=="Kristin" | ///
		        `var'=="Chrissy" | `var'=="Krissy" | `var'=="Chrissi"
	}

*Christoph*
foreach var of varlist netpn1 	{
		replace `var'="Christoph" if `var'=="Christoff" | `var'=="Chrsitoph" | `var'=="Christof"
	}

*Christopher*
foreach var of varlist netpn1	{
		replace `var'="Christopher" if `var'=="Christoher" | `var'=="Christoper"
	}

*Cindy*
foreach var of varlist netpn1 	{
		replace `var'="Cindy" if `var'=="Sindy" 
	}

*Claudia*
foreach var of varlist netpn1 	{
		replace `var'="Claudie" if `var'=="Klaudie" | `var'=="Claudja" | `var'=="Klaudja"
	}

*Clemens*
foreach var of varlist netpn1	{
		replace `var'="Clemens" if `var'=="Klemens"
	}

*Constance*
foreach var of varlist netpn1 	{
		replace `var'="Constance" if `var'=="Conny"
	}
	
*Darja*
foreach var of varlist netpn1 	{
		replace `var'="Darja" if `var'=="Daria" | `var'=="Dariachenoa (Zwillinge)"
	}

*Denise*
foreach var of varlist netpn1	{
		replace `var'="Denise" if `var'=="Dènise" | `var'=="Deniese" | `var'=="Dèniese" | ///
		        `var'=="Marie-Denise" | `var'=="DéNise" 
	} 

*Dennis*
foreach var of varlist netpn1 	{
		replace `var'="Dennis" if `var'=="Dènnis" | `var'=="Denis" | `var'=="Deniz" | ///
		        `var'=="Denniz"
	}

*Denny*
foreach var of varlist netpn1 	{
		replace `var'="Denny" if `var'=="Danny" | `var'=="Danni" | `var'=="Denni" | `var'=="Dany"
	}

*Dieter*
foreach var of varlist netpn1 	{
		replace `var'="Dieter" if `var'=="Didi"
	}

*Dilara*
foreach var of varlist netpn1	{
		replace `var'="Dilara" if `var'=="Dilara-Mada"
	}

*Domenique*
foreach var of varlist netpn1	{
		replace `var'="Domenique" if `var'=="Domènique" | `var'=="Dominik" | `var'=="DoméNique"
	}
	
*Dorothe*
foreach var of varlist netpn1 	{
		replace `var'="Dorothe" if `var'=="Dorothee" | `var'=="Doro" |  ///
		        `var'=="DorothéE"
	} 

*Edith*
foreach var of varlist netpn1 	{
		replace `var'="Edith" if `var'=="Edit"
	}

*Elisabeth*
foreach var of varlist netpn1	{
		replace `var'="Elisabeth" if `var'=="Elisabet" | `var'=="Elesabeth"
	}

*Ercan*
foreach var of varlist netpn1	{
		replace `var'="Ercan" if `var'=="Erkan"
	}

*Erik*
foreach var of varlist netpn1 	{
		replace `var'="Erik" if `var'=="Eric"
	}

*Esra*
foreach var of varlist netpn1 	{
		replace `var'="Esra" if `var'=="Isra"
	}

*Fabricio*
foreach var of varlist netpn1 	{
		replace `var'="Fabricio" if `var'=="Fabrizio"
	}

*Felicitas*
foreach var of varlist netpn1	{
		replace `var'="Felicitas" if `var'=="Feli" 
	}

	*Francesco*
foreach var of varlist netpn1 	{
		replace `var'="Francesco" if `var'=="Francessco"
	}
		
*Franziska*
foreach var of varlist netpn1 	{
		replace `var'="Franziska" if `var'=="Franzisca" | `var'=="Franzi" | ///
		        `var'=="Franciska" | `var'=="Francisca" 
	}

*Frederick*
foreach var of varlist netpn1 	{
		replace `var'="Frederick" if `var'=="Frèdèrick" | `var'=="Frederik" | ///
		        `var'=="Frèdèrik" | `var'=="Fredi" | `var'=="Frederik Niklas" | ///
				`var'=="FréDéRick"
	}	
	
*Gerrit*
foreach var of varlist netpn1 	{
		replace `var'="Gerrit" if `var'=="Gerit"
	}
	
*Günter*
foreach var of varlist netpn1 	{
		replace `var'="Günter" if `var'=="Guenther"
	}

*Hannah*
foreach var of varlist netpn1 	{
		replace `var'="Hannah" if `var'=="Hanna"
	}

*Hendrik*
foreach var of varlist netpn1 	{
		replace `var'="Hendrik" if `var'=="Hendrick" | `var'=="Henrik" | `var'=="Henrick"
	}

*Henning"
foreach var of varlist netpn1 	{
		replace `var'="Henning" if `var'=="Hennig"
	}
	
*Jacqueline*
foreach var of varlist netpn1	{
		replace `var'="Jacqueline" if `var'=="Jaqueline" | `var'=="Jacquelin" | ///
		`var'=="Jacky" | `var'=="Heike Jaqueline" | `var'=="Jaquelin"
	}
 
*Jakob*
foreach var of varlist netpn1 	{
		replace `var'="Jakob" if `var'=="Jackob"
	}

*Jennifer*
foreach var of varlist netpn1	{
		replace `var'="Jennifer" if `var'=="Jenny" | `var'=="Jeniffer" |`var'=="Jenni" | ///
		        `var'=="Jenniffer"
	}
	
*Johanna*
foreach var of varlist netpn1 	{
		replace `var'="Johanna" if `var'=="Johana" | `var'=="Johannah" | ///
		        `var'=="Joh. Gabi. Franz."
	}

*Johannes*
foreach var of varlist netpn1 	{
		replace `var'="Johannes" if `var'=="Johanes" | `var'=="Jo"
	}

*Jörg*
foreach var of varlist netpn1	{
		replace `var'="Jörg" if `var'=="Joerg"
	}

*Jörn*
foreach var of varlist netpn1 	{
		replace `var'="Jörn" if `var'=="Jöern" 
	}

*Josef*
foreach var of varlist netpn1	{
		replace `var'="Josef" if `var'=="Joseph" 
	}
	
*Julia*
foreach var of varlist netpn1	{
		replace `var'="Julia" if `var'=="Julja" | `var'=="Jule" 	
	}

*Julian*
foreach var of varlist netpn1 	{
		replace `var'="Julian" if `var'=="Jullian"
	}

*Kai*
foreach var of varlist netpn1	{
		replace `var'="Kai" if `var'=="Kay"  
	}

*Katharina*
foreach var of varlist netpn1	{
		replace `var'="Katharina" if `var'=="Katharine" | `var'=="Katarina"
	}

*Katherina*
foreach var of varlist netpn1 	{
		replace `var'="Katherina" if `var'=="Katerina"
	}

*Keno*
foreach var of varlist netpn1 	{
		replace `var'="Keno" if `var'=="Kemo"
	}

*Kevin*
foreach var of varlist netpn1 	{
		replace `var'="Kevin" if `var'=="Cevin" | `var'=="Kev" 
	}
	
*Kimberly*
foreach var of varlist netpn1 	{
		replace `var'="Kimberly" if `var'=="Kimberley"
	}
	
*Leonhard*
foreach var of varlist netpn1	{
		replace `var'="Leonhard" if `var'=="Leo"
	}

*Louisa*
foreach var of varlist netpn1	{
		replace `var'="Louisa" if `var'=="Lousia" 
	}

*Lukas*
foreach var of varlist netpn1	{
		replace `var'="Lukas" if `var'=="Lucas"
	}
	
*Madeleine*
foreach var of varlist netpn1	{
		replace `var'="Madeleine" if `var'=="Madeline"
	}
	
*Maike*
foreach var of varlist netpn1 	{
		replace `var'="Maike" if `var'=="Maiko" | `var'=="Meike" | `var'=="Meiko" | ///
		        `var'=="Mayke" | `var'=="Mayle"
	}

*Marcell*
foreach var of varlist netpn1 	{
		replace `var'="Marcell" if `var'=="Marcel" 
	}
	
*Mareike*
foreach var of varlist netpn1	{
		replace `var'="Mareike" if `var'=="Maraike" | `var'=="Maricke" 
	}
	
*Margarethe*
foreach var of varlist netpn1 	{
		replace `var'="Margarethe" if `var'=="Margarete"
	}

*Matthias*
foreach var of varlist netpn1	{
		replace `var'="Matthias" if `var'=="Mathias" | `var'=="Mattias" | `var'=="Mathias" | ///
				`var'=="Matse" | `var'=="Matti" | `var'=="Matthies" | `var'=="Matihas"
	}

*Mathis*
foreach var of varlist netpn1 	{
		replace `var'="Mathis" if `var'=="Matthis" | `var'=="Mattis" | `var'=="Mathi"
	}

*Maximillian*
foreach var of varlist netpn1	{
		replace `var'="Maximillian" if `var'=="Max" | `var'=="Maximilian" | `var'=="Maximilia" | ///
		        `var'=="Maixmilian"
	}

*Maximiliane*
foreach var of varlist netpn1 	{
		replace `var'="Maximiliane" if `var'=="Maxi"
	}

*Melanie*
foreach var of varlist netpn1	{
		replace `var'="Melanie" if `var'=="Mellanie" | `var'=="Mellani" | `var'=="Melani" | ///
		        `var'=="Mellany" | `var'=="Mel" | `var'=="Mell" 
	}
	
*Melina*
foreach var of varlist netpn1	{
		replace `var'="Melina" if `var'=="Mellina"
	}

*Melissa*
foreach var of varlist netpn1 	{
		replace `var'="Melissa" if `var'=="Mellisa"
	}

*Michelle*
foreach var of varlist netpn1 	{
		replace `var'="Michelle" if `var'=="Michele" | ///
		        `var'=="Michèle"
	}
	
*Mieke*
foreach var of varlist netpn1 	{
		replace `var'="Mieke" if `var'=="Mielie"
	}

*Mirjam"
foreach var of varlist netpn1 	{
		replace `var'="Mirjam" if `var'=="Mirijam" | `var'=="Mirjan" | `var'=="Miri" | ///
		        `var'=="Miry" | `var'=="Miriam" | `var'=="Mell" 
	}

*Mirko*
foreach var of varlist netpn1	{
		replace `var'="Mirko" if `var'=="Mirco"
	}
	
*Monika*
foreach var of varlist netpn1 	{
		replace `var'="Monika" if `var'=="Monica" 
	}

*Nadja*
foreach var of varlist netpn1 	{
		replace `var'="Nadja" if `var'=="Nadia"
	}

*Nastja*
foreach var of varlist netpn1 	{
		replace `var'="Nastja" if `var'=="Nastia"
	}
	
*Nathalie*
foreach var of varlist netpn1 	{
		replace `var'="Nathalie" if `var'=="Natalie"
	}

*Nico*
foreach var of varlist netpn1 	{
		replace `var'="Nico" if `var'=="Niko"
	}

*Nicole*
foreach var of varlist netpn1 	{
		replace `var'="Nikole" if `var'=="Nicolle" | `var'=="Nicol"
	}

*Niklas*
foreach var of varlist netpn1 	{
		replace `var'="Niklas" if `var'=="Nicklas" 
	}

*Nils*
foreach var of varlist netpn1 	{
		replace `var'="Nils" if `var'=="Niels"
	}

*Oliver*
foreach var of varlist netpn1 	{
		replace `var'="Oliver" if `var'=="Olliver" | `var'=="Ollivér" | `var'=="Olivér" | ///
		        `var'=="Oli" | `var'=="Olli"
	}
	
*Patrik*
foreach var of varlist netpn1	{
		replace `var'="Patrik" if `var'=="Patrique" | `var'=="Patrick" | `var'=="Patryk"
	}

*Phillip*
foreach var of varlist netpn1 	{
		replace `var'="Phillip" if `var'=="Phillipp" | `var'=="Philip" | `var'=="Philipp" | ///
		        `var'=="Philli" | `var'=="Phili" | `var'=="Phips" 
	}

*Rainer*
foreach var of varlist netpn1	{
		replace `var'="Rainer" if `var'=="Reiner" 
	}

*Ralf*
foreach var of varlist netpn1 	{
		replace `var'="Ralf" if `var'=="Ralph" 
	}

*Randolph*
foreach var of varlist netpn1	{
		replace `var'="Randoph" if `var'=="Randolf" | `var'=="Randi" | `var'=="Randy"
	}
 
*Rebecca*
foreach var of varlist netpn1 	{
		replace `var'="Rebecca" if `var'=="Rebekka" | `var'=="Rebeka" | `var'=="Rebeca"
	}
 
*Rene*
foreach var of varlist netpn1 	{
		replace `var'="Rene" if `var'=="Renè" | `var'=="René" | `var'=="René-Jerome" | ///
		        `var'=="Tommy-Rene" | `var'=="Rene´" | `var'=="Renee" 
	}

*Richard*
foreach var of varlist netpn1 	{
		replace `var'="Richard" if `var'=="Richhard" | `var'=="Rich" | `var'=="Richi" | ///
		        `var'=="Richy"
	}
	
*Robin*
foreach var of varlist netpn1 	{
		replace `var'="Robin" if `var'=="Robbin" 
	}

*Ronny*
foreach var of varlist netpn1 	{
		replace `var'="Ronny" if `var'=="Ronni" | `var'=="Ronney"
	}

*Sandra*
foreach var of varlist netpn1	{
		replace `var'="Sandra" if `var'=="Sandrah" 
	}

*Sarah*
foreach var of varlist netpn1 	{
		replace `var'="Sarah" if `var'=="Sara" | `var'=="Sahra" |  ///
		        `var'=="Saraha"
	}

*Sebastian*
foreach var of varlist netpn1	{
		replace `var'="Sebastian" if `var'=="Seb" | `var'=="Sebi" | `var'=="Basti"
	}

*Silvana*
foreach var of varlist netpn1 	{
		replace `var'="Silvana" if `var'=="Sivana" | `var'=="Sylvana"
	}

*Silvia*
foreach var of varlist netpn1 	{
		replace `var'="Silvia" if `var'=="Silva" | `var'=="Sylvia"
	}

*Sophie*
foreach var of varlist netpn1 	{
		replace `var'="Sophie" if `var'=="Sofie" | `var'=="Sofi" | `var'=="Sophi" 
	}

*Stefan*
foreach var of varlist netpn1 	{
		replace `var'="Stefan" if `var'=="Stephan" | `var'=="Steffan"
	}

*Stefanie*
foreach var of varlist netpn1 	{
		replace `var'="Stefanie" if `var'=="Stephanie" | `var'=="Stefani" | `var'=="Steff" ///
		| `var'=="Steffi" 
	}
	
*Steffen*
foreach var of varlist netpn1	{
		replace `var'="Steffen" if `var'=="Stephen" | `var'=="Stefen"
	}
	
*Susanne*
foreach var of varlist netpn1 	{
		replace `var'="Susanne" if `var'=="Sussanne" 
	}

*Tatjana*
foreach var of varlist netpn1 	{
		replace `var'="Tatjana" if `var'=="Tatiana" 
	}

*Theo*
foreach var of varlist netpn1 	{
		replace `var'="Theo" if `var'=="Theodor" | `var'=="Theodore"
	}

*Theresa*
foreach var of varlist netpn1 	{
		replace `var'="Theresa" if `var'=="Teresa" 
	}

*Thomas*
foreach var of varlist netpn1	{
		replace `var'="Thomas" if `var'=="Tomas" | `var'=="Tom"
	}

*Tilman*
foreach var of varlist netpn1	{
		replace `var'="Tilman" if `var'=="Tillman" | `var'=="Tillmann" | ///
		        `var'=="Tilmann"
	}

*Tobias*
foreach var of varlist netpn1 {
		replace `var'="Tobias" if `var'=="Tobi" | `var'=="Toby" 
	}

*Toni*
foreach var of varlist netpn1 {
		replace `var'="Toni" if `var'=="Tony" 
	}

*Verena*
foreach var of varlist netpn1 {
		replace `var'="Verena" if `var'=="Werena"
	}
	
*Veronika*
foreach var of varlist netpn1	{
		replace `var'="Veronika" if `var'=="Veronica"
	}
	
*Viktor*
foreach var of varlist netpn1 {
		replace `var'="Viktor" if `var'=="Victor"
	}
	
*Viktoria*
foreach var of varlist netpn1	{
		replace `var'="Viktoria" if `var'=="Victoria"
	}
	
*Vivien*
foreach var of varlist netpn1 {
		replace `var'="Vivien" if `var'=="Vivian"
	}
	
*Yannick*
foreach var of varlist netpn1	{
		replace `var'="Yannick" if `var'=="Yannic" | `var'=="Yannik"
	}

recode net5p net7p net10p net11p net12p net13p net14p (-1=.) (-2=.) (-4=.)

gen net10p_copy = net10p

recode net10p (7/12=0) (12.0001/17=1) (17.0001/22=2) (22.0001/27 =3) (27.0001/32 = 4) (32.0001/37=5) (37.0001/42 = 6) ///
(42.0001/47=7) (47.0001/52=8) (52.0001/57=9) (57.0001/62=10) (62.0001/67=11) (67.0001/72=12) (72.0001/99=13) 

gen idusing = _n

save "$datapath\link2.dta", replace


*******************************************
**** Preparation for Record Linkage, W4 ***
*******************************************

use "$datapath\anchor4.dta", clear

keep id net10p1-net10p28 net11p1-net11p28 net5p1-net5p28 net7p1-net7p28 net12p1-net12p28 net13p1-net13p28 net14p1-net14p28 intm inty

replace id = id/1000

tab1 intm inty

rename intm intm4
rename inty inty4

merge 1:1 id using "$datapath\intdate_w2.dta", keep(match master)

drop _merge

merge 1:1 id using "$datapath\names4.dta", keep(match master)

drop _merge 

rename str_netp1n netpn1
rename str_netp2n netpn2
rename str_netp3n netpn3
rename str_netp4n netpn4
rename str_netp5n netpn5
rename str_netp6n netpn6
rename str_netp7n netpn7
rename str_netp8n netpn8
rename str_netp9n netpn9
rename str_netp10n netpn10
rename str_netp11n netpn11
rename str_netp12n netpn12
rename str_netp13n netpn13
rename str_netp14n netpn14
rename str_netp15n netpn15
rename str_netp16n netpn16
rename str_netp17n netpn17
rename str_netp18n netpn18
rename str_netp19n netpn19
rename str_netp20n netpn20
rename str_netp21n netpn21
rename str_netp22n netpn22
rename str_netp23n netpn23
rename str_netp24n netpn24
rename str_netp25n netpn25
rename str_netp26n netpn26
rename str_netp27n netpn27
rename str_netp28n netpn28

drop str_netp29n-str_netp39n

reshape long netpn net10p net11p net5p net7p net12p net13p net14p, i(id) j(nwpnr)

* Deletion of abbrevations (for second first names or last names)

split netpn, destring

drop netpn2 netpn3 netpn4

drop if netpn1 =="-3" 
drop if netpn1 =="-6" 
drop if netpn1 == ""
drop if net10p == -3 & net11p == -3

* Cleaning of names

*Aileen*
foreach var of varlist netpn1						{
		replace `var'="Aileen" if `var'=="Ailleen" 
	}

*Alexander*
foreach var of varlist netpn1 	{
		replace `var'="Alexander" if `var'=="Allexander" | `var'=="Alex"
	}

*Alisa*
foreach var of varlist netpn1	{
		replace `var'="Alisa" if `var'=="Alisa-Nina" 
	}

*Amelie*
foreach var of varlist netpn1 	{
		replace `var'="Amelie" if `var'=="Ammelie" | `var'=="Ammely" | `var'=="Amely"
	} 

*Andre*
foreach var of varlist netpn1 	{
		replace `var'="Andre" if `var'=="Andrè" | `var'=="Anré" | `var'=="André" | ///
				`var'=="Andre´" 
	}

*Anja*
foreach var of varlist netpn1	{
		replace `var'="Anja" if `var'=="Ania"
	}

*Annabell*
foreach var of varlist netpn1 	{
		replace `var'="Annabell" if `var'=="Annabel"
	}
	
*Annelie*
foreach var of varlist netpn1 	{
		replace `var'="Annelie" if `var'=="Annelie-Sophie"
	}

*Annett*
foreach var of varlist netpn1 	{
		replace `var'="Annett" if `var'=="Anett" | `var'=="Annek" | `var'=="Anete" | ///
				`var'=="Anette" | `var'=="Annette" | `var'=="Annete"
	}
	
*Annegret*
foreach var of varlist netpn1	{
		replace `var'="Annegret" if `var'=="Anne-Gret"
	}
	
*Annkatrin*
foreach var of varlist netpn1 	{
		replace `var'="Annkatrin" if `var'=="Ann-Katrin" | `var'=="Annkathrin" | ///
				`var'=="Ann-Kathrin"
	}
	
*Astrid"
foreach var of varlist netpn1	{
		replace `var'="Astrid" if `var'=="Astridt"
	}
	
*Bastian"
foreach var of varlist netpn1 	{
		replace `var'="Bastian" if `var'=="Basti"
	}
	
*Benedikt*
foreach var of varlist netpn1	{
		replace `var'="Benedikt" if `var'=="Benedict"
	}
	
*Benjamin*
foreach var of varlist netpn1 	{
		replace `var'="Benjamin" if `var'=="Beniamin" | `var'=="Benni" 
	}

*Bianca*
foreach var of varlist netpn1 	{
		replace `var'="Bianca" if `var'=="Bianka" | `var'=="Bibbi" | `var'=="Bibby"
	}

*Boris*
foreach var of varlist netpn1	{
		replace `var'="Boris" if `var'=="Borris"
	}

*Burak*
foreach var of varlist netpn1 	{
		replace `var'="Burak" if `var'=="Burak-Nazif"
	}
	
*Carla*
foreach var of varlist netpn1 	{
		replace `var'="Carla" if `var'=="Zwilling"
	}
	
*Carmen*
foreach var of varlist netpn1	{
		replace `var'="Carmen" if `var'=="Karmen"
	}

*Catrin*
foreach var of varlist netpn1	{
		replace `var'="Catrin" if `var'=="Cathrin"
	}
	
*Cecilia*
foreach var of varlist netpn1 	{
		replace `var'="Cecilia" if `var'=="Cäcilia"
	}
	
*Cedric*
foreach var of varlist netpn1 {
		replace `var'="Cedric" if `var'=="CéDric"
	}
	
*Celine*
foreach var of varlist netpn1 	{
		replace `var'="Celine" if `var'=="Cèline" | `var'=="Cèlin" | `var'=="Celin" | ///
		        `var'=="CéLine"
	}

*Chanice*
foreach var of varlist netpn1 	{
		replace `var'="Chanice" if `var'=="Charice"
	}

*Christian*
foreach var of varlist netpn1 	{
		replace `var'="Christian" if `var'=="Kristian" | `var'=="Christan"
	}

*Christina*
foreach var of varlist netpn1	{
		replace `var'="Christina" if `var'=="Kristina"
	}

*Christine*
foreach var of varlist netpn1 	{
		replace `var'="Christine" if `var'=="Kristine" | `var'=="Christin" | `var'=="Kristin" | ///
		        `var'=="Chrissy" | `var'=="Krissy" | `var'=="Chrissi"
	}

*Christoph*
foreach var of varlist netpn1 	{
		replace `var'="Christoph" if `var'=="Christoff" | `var'=="Chrsitoph" | `var'=="Christof"
	}

*Christopher*
foreach var of varlist netpn1	{
		replace `var'="Christopher" if `var'=="Christoher" | `var'=="Christoper"
	}

*Cindy*
foreach var of varlist netpn1 	{
		replace `var'="Cindy" if `var'=="Sindy" 
	}

*Claudia*
foreach var of varlist netpn1 	{
		replace `var'="Claudie" if `var'=="Klaudie" | `var'=="Claudja" | `var'=="Klaudja"
	}

*Clemens*
foreach var of varlist netpn1	{
		replace `var'="Clemens" if `var'=="Klemens"
	}

*Constance*
foreach var of varlist netpn1 	{
		replace `var'="Constance" if `var'=="Conny"
	}
	
*Darja*
foreach var of varlist netpn1 	{
		replace `var'="Darja" if `var'=="Daria" | `var'=="Dariachenoa (Zwillinge)"
	}

*Denise*
foreach var of varlist netpn1	{
		replace `var'="Denise" if `var'=="Dènise" | `var'=="Deniese" | `var'=="Dèniese" | ///
		        `var'=="Marie-Denise" | `var'=="DéNise" 
	} 

*Dennis*
foreach var of varlist netpn1 	{
		replace `var'="Dennis" if `var'=="Dènnis" | `var'=="Denis" | `var'=="Deniz" | ///
		        `var'=="Denniz"
	}

*Denny*
foreach var of varlist netpn1 	{
		replace `var'="Denny" if `var'=="Danny" | `var'=="Danni" | `var'=="Denni" | `var'=="Dany"
	}

*Dieter*
foreach var of varlist netpn1 	{
		replace `var'="Dieter" if `var'=="Didi"
	}

*Dilara*
foreach var of varlist netpn1	{
		replace `var'="Dilara" if `var'=="Dilara-Mada"
	}

*Domenique*
foreach var of varlist netpn1	{
		replace `var'="Domenique" if `var'=="Domènique" | `var'=="Dominik" | `var'=="DoméNique"
	}
	
*Dorothe*
foreach var of varlist netpn1 	{
		replace `var'="Dorothe" if `var'=="Dorothee" | `var'=="Doro" |  ///
		        `var'=="DorothéE"
	} 

*Edith*
foreach var of varlist netpn1 	{
		replace `var'="Edith" if `var'=="Edit"
	}

*Elisabeth*
foreach var of varlist netpn1	{
		replace `var'="Elisabeth" if `var'=="Elisabet" | `var'=="Elesabeth"
	}

*Ercan*
foreach var of varlist netpn1	{
		replace `var'="Ercan" if `var'=="Erkan"
	}

*Erik*
foreach var of varlist netpn1 	{
		replace `var'="Erik" if `var'=="Eric"
	}

*Esra*
foreach var of varlist netpn1 	{
		replace `var'="Esra" if `var'=="Isra"
	}

*Fabricio*
foreach var of varlist netpn1 	{
		replace `var'="Fabricio" if `var'=="Fabrizio"
	}

*Felicitas*
foreach var of varlist netpn1	{
		replace `var'="Felicitas" if `var'=="Feli" 
	}

	*Francesco*
foreach var of varlist netpn1 	{
		replace `var'="Francesco" if `var'=="Francessco"
	}
		
*Franziska*
foreach var of varlist netpn1 	{
		replace `var'="Franziska" if `var'=="Franzisca" | `var'=="Franzi" | ///
		        `var'=="Franciska" | `var'=="Francisca" 
	}

*Frederick*
foreach var of varlist netpn1 	{
		replace `var'="Frederick" if `var'=="Frèdèrick" | `var'=="Frederik" | ///
		        `var'=="Frèdèrik" | `var'=="Fredi" | `var'=="Frederik Niklas" | ///
				`var'=="FréDéRick"
	}	
	
*Gerrit*
foreach var of varlist netpn1 	{
		replace `var'="Gerrit" if `var'=="Gerit"
	}
	
*Günter*
foreach var of varlist netpn1 	{
		replace `var'="Günter" if `var'=="Guenther"
	}

*Hannah*
foreach var of varlist netpn1 	{
		replace `var'="Hannah" if `var'=="Hanna"
	}

*Hendrik*
foreach var of varlist netpn1 	{
		replace `var'="Hendrik" if `var'=="Hendrick" | `var'=="Henrik" | `var'=="Henrick"
	}

*Henning"
foreach var of varlist netpn1 	{
		replace `var'="Henning" if `var'=="Hennig"
	}
	
*Jacqueline*
foreach var of varlist netpn1	{
		replace `var'="Jacqueline" if `var'=="Jaqueline" | `var'=="Jacquelin" | ///
		`var'=="Jacky" | `var'=="Heike Jaqueline" | `var'=="Jaquelin"
	}
 
*Jakob*
foreach var of varlist netpn1 	{
		replace `var'="Jakob" if `var'=="Jackob"
	}

*Jennifer*
foreach var of varlist netpn1	{
		replace `var'="Jennifer" if `var'=="Jenny" | `var'=="Jeniffer" |`var'=="Jenni" | ///
		        `var'=="Jenniffer"
	}
	
*Johanna*
foreach var of varlist netpn1 	{
		replace `var'="Johanna" if `var'=="Johana" | `var'=="Johannah" | ///
		        `var'=="Joh. Gabi. Franz."
	}

*Johannes*
foreach var of varlist netpn1 	{
		replace `var'="Johannes" if `var'=="Johanes" | `var'=="Jo"
	}

*Jörg*
foreach var of varlist netpn1	{
		replace `var'="Jörg" if `var'=="Joerg"
	}

*Jörn*
foreach var of varlist netpn1 	{
		replace `var'="Jörn" if `var'=="Jöern" 
	}

*Josef*
foreach var of varlist netpn1	{
		replace `var'="Josef" if `var'=="Joseph" 
	}
	
*Julia*
foreach var of varlist netpn1	{
		replace `var'="Julia" if `var'=="Julja" | `var'=="Jule" 	
	}

*Julian*
foreach var of varlist netpn1 	{
		replace `var'="Julian" if `var'=="Jullian"
	}

*Kai*
foreach var of varlist netpn1	{
		replace `var'="Kai" if `var'=="Kay"  
	}

*Katharina*
foreach var of varlist netpn1	{
		replace `var'="Katharina" if `var'=="Katharine" | `var'=="Katarina"
	}

*Katherina*
foreach var of varlist netpn1 	{
		replace `var'="Katherina" if `var'=="Katerina"
	}

*Keno*
foreach var of varlist netpn1 	{
		replace `var'="Keno" if `var'=="Kemo"
	}

*Kevin*
foreach var of varlist netpn1 	{
		replace `var'="Kevin" if `var'=="Cevin" | `var'=="Kev" 
	}
	
*Kimberly*
foreach var of varlist netpn1 	{
		replace `var'="Kimberly" if `var'=="Kimberley"
	}
	
*Leonhard*
foreach var of varlist netpn1	{
		replace `var'="Leonhard" if `var'=="Leo"
	}

*Louisa*
foreach var of varlist netpn1	{
		replace `var'="Louisa" if `var'=="Lousia" 
	}

*Lukas*
foreach var of varlist netpn1	{
		replace `var'="Lukas" if `var'=="Lucas"
	}
	
*Madeleine*
foreach var of varlist netpn1	{
		replace `var'="Madeleine" if `var'=="Madeline"
	}
	
*Maike*
foreach var of varlist netpn1 	{
		replace `var'="Maike" if `var'=="Maiko" | `var'=="Meike" | `var'=="Meiko" | ///
		        `var'=="Mayke" | `var'=="Mayle"
	}

*Marcell*
foreach var of varlist netpn1 	{
		replace `var'="Marcell" if `var'=="Marcel" 
	}
	
*Mareike*
foreach var of varlist netpn1	{
		replace `var'="Mareike" if `var'=="Maraike" | `var'=="Maricke" 
	}
	
*Margarethe*
foreach var of varlist netpn1 	{
		replace `var'="Margarethe" if `var'=="Margarete"
	}

*Matthias*
foreach var of varlist netpn1	{
		replace `var'="Matthias" if `var'=="Mathias" | `var'=="Mattias" | `var'=="Mathias" | ///
				`var'=="Matse" | `var'=="Matti" | `var'=="Matthies" | `var'=="Matihas"
	}

*Mathis*
foreach var of varlist netpn1 	{
		replace `var'="Mathis" if `var'=="Matthis" | `var'=="Mattis" | `var'=="Mathi"
	}

*Maximillian*
foreach var of varlist netpn1	{
		replace `var'="Maximillian" if `var'=="Max" | `var'=="Maximilian" | `var'=="Maximilia" | ///
		        `var'=="Maixmilian"
	}

*Maximiliane*
foreach var of varlist netpn1 	{
		replace `var'="Maximiliane" if `var'=="Maxi"
	}

*Melanie*
foreach var of varlist netpn1	{
		replace `var'="Melanie" if `var'=="Mellanie" | `var'=="Mellani" | `var'=="Melani" | ///
		        `var'=="Mellany" | `var'=="Mel" | `var'=="Mell" 
	}
	
*Melina*
foreach var of varlist netpn1	{
		replace `var'="Melina" if `var'=="Mellina"
	}

*Melissa*
foreach var of varlist netpn1 	{
		replace `var'="Melissa" if `var'=="Mellisa"
	}

*Michelle*
foreach var of varlist netpn1 	{
		replace `var'="Michelle" if `var'=="Michele" | ///
		        `var'=="Michèle"
	}
	
*Mieke*
foreach var of varlist netpn1 	{
		replace `var'="Mieke" if `var'=="Mielie"
	}

*Mirjam"
foreach var of varlist netpn1 	{
		replace `var'="Mirjam" if `var'=="Mirijam" | `var'=="Mirjan" | `var'=="Miri" | ///
		        `var'=="Miry" | `var'=="Miriam" | `var'=="Mell" 
	}

*Mirko*
foreach var of varlist netpn1	{
		replace `var'="Mirko" if `var'=="Mirco"
	}
	
*Monika*
foreach var of varlist netpn1 	{
		replace `var'="Monika" if `var'=="Monica" 
	}

*Nadja*
foreach var of varlist netpn1 	{
		replace `var'="Nadja" if `var'=="Nadia"
	}

*Nastja*
foreach var of varlist netpn1 	{
		replace `var'="Nastja" if `var'=="Nastia"
	}
	
*Nathalie*
foreach var of varlist netpn1 	{
		replace `var'="Nathalie" if `var'=="Natalie"
	}

*Nico*
foreach var of varlist netpn1 	{
		replace `var'="Nico" if `var'=="Niko"
	}

*Nicole*
foreach var of varlist netpn1 	{
		replace `var'="Nikole" if `var'=="Nicolle" | `var'=="Nicol"
	}

*Niklas*
foreach var of varlist netpn1 	{
		replace `var'="Niklas" if `var'=="Nicklas" 
	}

*Nils*
foreach var of varlist netpn1 	{
		replace `var'="Nils" if `var'=="Niels"
	}

*Oliver*
foreach var of varlist netpn1 	{
		replace `var'="Oliver" if `var'=="Olliver" | `var'=="Ollivér" | `var'=="Olivér" | ///
		        `var'=="Oli" | `var'=="Olli"
	}
	
*Patrik*
foreach var of varlist netpn1	{
		replace `var'="Patrik" if `var'=="Patrique" | `var'=="Patrick" | `var'=="Patryk"
	}

*Phillip*
foreach var of varlist netpn1 	{
		replace `var'="Phillip" if `var'=="Phillipp" | `var'=="Philip" | `var'=="Philipp" | ///
		        `var'=="Philli" | `var'=="Phili" | `var'=="Phips" 
	}

*Rainer*
foreach var of varlist netpn1	{
		replace `var'="Rainer" if `var'=="Reiner" 
	}

*Ralf*
foreach var of varlist netpn1 	{
		replace `var'="Ralf" if `var'=="Ralph" 
	}

*Randolph*
foreach var of varlist netpn1	{
		replace `var'="Randoph" if `var'=="Randolf" | `var'=="Randi" | `var'=="Randy"
	}
 
*Rebecca*
foreach var of varlist netpn1 	{
		replace `var'="Rebecca" if `var'=="Rebekka" | `var'=="Rebeka" | `var'=="Rebeca"
	}
 
*Rene*
foreach var of varlist netpn1 	{
		replace `var'="Rene" if `var'=="Renè" | `var'=="René" | `var'=="René-Jerome" | ///
		        `var'=="Tommy-Rene" | `var'=="Rene´" | `var'=="Renee" 
	}

*Richard*
foreach var of varlist netpn1 	{
		replace `var'="Richard" if `var'=="Richhard" | `var'=="Rich" | `var'=="Richi" | ///
		        `var'=="Richy"
	}
	
*Robin*
foreach var of varlist netpn1 	{
		replace `var'="Robin" if `var'=="Robbin" 
	}

*Ronny*
foreach var of varlist netpn1 	{
		replace `var'="Ronny" if `var'=="Ronni" | `var'=="Ronney"
	}

*Sandra*
foreach var of varlist netpn1	{
		replace `var'="Sandra" if `var'=="Sandrah" 
	}

*Sarah*
foreach var of varlist netpn1 	{
		replace `var'="Sarah" if `var'=="Sara" | `var'=="Sahra" |  ///
		        `var'=="Saraha"
	}

*Sebastian*
foreach var of varlist netpn1	{
		replace `var'="Sebastian" if `var'=="Seb" | `var'=="Sebi" | `var'=="Basti"
	}

*Silvana*
foreach var of varlist netpn1 	{
		replace `var'="Silvana" if `var'=="Sivana" | `var'=="Sylvana"
	}

*Silvia*
foreach var of varlist netpn1 	{
		replace `var'="Silvia" if `var'=="Silva" | `var'=="Sylvia"
	}

*Sophie*
foreach var of varlist netpn1 	{
		replace `var'="Sophie" if `var'=="Sofie" | `var'=="Sofi" | `var'=="Sophi" 
	}

*Stefan*
foreach var of varlist netpn1 	{
		replace `var'="Stefan" if `var'=="Stephan" | `var'=="Steffan"
	}

*Stefanie*
foreach var of varlist netpn1 	{
		replace `var'="Stefanie" if `var'=="Stephanie" | `var'=="Stefani" | `var'=="Steff" ///
		| `var'=="Steffi" 
	}
	
*Steffen*
foreach var of varlist netpn1	{
		replace `var'="Steffen" if `var'=="Stephen" | `var'=="Stefen"
	}
	
*Susanne*
foreach var of varlist netpn1 	{
		replace `var'="Susanne" if `var'=="Sussanne" 
	}

*Tatjana*
foreach var of varlist netpn1 	{
		replace `var'="Tatjana" if `var'=="Tatiana" 
	}

*Theo*
foreach var of varlist netpn1 	{
		replace `var'="Theo" if `var'=="Theodor" | `var'=="Theodore"
	}

*Theresa*
foreach var of varlist netpn1 	{
		replace `var'="Theresa" if `var'=="Teresa" 
	}

*Thomas*
foreach var of varlist netpn1	{
		replace `var'="Thomas" if `var'=="Tomas" | `var'=="Tom"
	}

*Tilman*
foreach var of varlist netpn1	{
		replace `var'="Tilman" if `var'=="Tillman" | `var'=="Tillmann" | ///
		        `var'=="Tilmann"
	}

*Tobias*
foreach var of varlist netpn1 {
		replace `var'="Tobias" if `var'=="Tobi" | `var'=="Toby" 
	}

*Toni*
foreach var of varlist netpn1 {
		replace `var'="Toni" if `var'=="Tony" 
	}

*Verena*
foreach var of varlist netpn1 {
		replace `var'="Verena" if `var'=="Werena"
	}
	
*Veronika*
foreach var of varlist netpn1	{
		replace `var'="Veronika" if `var'=="Veronica"
	}
	
*Viktor*
foreach var of varlist netpn1 {
		replace `var'="Viktor" if `var'=="Victor"
	}
	
*Viktoria*
foreach var of varlist netpn1	{
		replace `var'="Viktoria" if `var'=="Victoria"
	}
	
*Vivien*
foreach var of varlist netpn1 {
		replace `var'="Vivien" if `var'=="Vivian"
	}
	
*Yannick*
foreach var of varlist netpn1	{
		replace `var'="Yannick" if `var'=="Yannic" | `var'=="Yannik"
	}
	
gen idmaster = _n

recode net5p net7p net10p net11p net12p net13p net14p (-1=.) (-2=.) (-4=.)

gen net10p_copy = net10p

gen intdate_w2 = (inty * 12) - (12 - intm)
gen intdate_w4 = (inty4 * 12) - (12 - intm4)
gen intdiff = intdate_w4 - intdate_w2
replace intdiff = intdiff / 12 
replace net10p = net10p - intdiff 
recode net10p (7/12=0) (12.0001/17=1) (17.0001/22=2) (22.0001/27 =3) (27.0001/32 = 4) (32.0001/37=5) (37.0001/42 = 6) ///
(42.0001/47=7) (47.0001/52=8) (52.0001/57=9) (57.0001/62=10) (62.0001/67=11) (67.0001/72=12) (72.0001/99=13) 

save "$datapath\link4.dta", replace

keep id idmaster net5p net7p net10p net11p net12p net13p net14p net10p_copy

rename net5p net5p_w4 
rename net7p net7p_w4 
rename net10p net10p_w4 
rename net11p net11p_w4 
rename net12p net12p_w4 
rename net13p net13p_w4
rename net14p net14p_w4 
rename net10p_copy net10p_copy_w4

save "$datapath\w4_nwdesk.dta", replace


***********************
**** Record Linkage ***
***********************

use "$datapath\link2.dta", clear

reclink netpn1 net10p net11p id using link4.dta, gen(myscore) idm(idusing) idu(idmaster) wmatch (10 2 2 10) wnomatch (8 2 6 10) ///
required(id)

* Manual review of matches 

order id Uid myscore netpn1 Unetpn1 net10p Unet10p net11p Unet11p idusing

sort myscore

gen diff = Unet10p - net10p

replace _merge = 1 if idusing == 20308 
replace _merge = 1 if idusing == 8098 
replace _merge = 1 if idusing == 16770
replace _merge = 1 if idusing == 12172
replace _merge = 1 if idusing == 17853
replace _merge = 1 if idusing == 4379
replace _merge = 1 if idusing == 4101
replace _merge = 1 if idusing == 14256
replace _merge = 1 if idusing == 3408
replace _merge = 1 if idusing == 15431
replace _merge = 1 if idusing == 11621
replace _merge = 1 if idusing == 6505
replace _merge = 1 if idusing == 19011
replace _merge = 1 if idusing == 19732
replace _merge = 1 if idusing == 19674
replace _merge = 1 if idusing == 15860
replace _merge = 1 if idusing == 1431
replace _merge = 1 if idusing == 12327
replace _merge = 1 if idusing == 22431
replace _merge = 1 if idusing == 12434
replace _merge = 1 if idusing == 19492
replace _merge = 1 if idusing == 5632
replace _merge = 1 if idusing == 19493
replace _merge = 1 if idusing == 10364
replace _merge = 1 if idusing == 24948
replace _merge = 1 if idusing == 22113
replace _merge = 1 if idusing == 3143
replace _merge = 1 if idusing == 26487
replace _merge = 1 if idusing == 3101
replace _merge = 1 if idusing == 22447
replace _merge = 1 if idusing == 18365
replace _merge = 1 if idusing == 5521
replace _merge = 1 if idusing == 1113
replace _merge = 1 if idusing == 18792
replace _merge = 1 if idusing == 8082
replace _merge = 1 if idusing == 25260
replace _merge = 1 if idusing == 21692
replace _merge = 1 if idusing == 9853
replace _merge = 1 if idusing == 2695
replace _merge = 1 if idusing == 11082
replace _merge = 1 if idusing == 25732
replace _merge = 1 if idusing == 3720
replace _merge = 1 if idusing == 5393
replace _merge = 1 if idusing == 20932
replace _merge = 1 if idusing == 13354
replace _merge = 1 if idusing == 13406
replace _merge = 1 if idusing == 6135
replace _merge = 1 if idusing == 613
replace _merge = 1 if idusing == 5187
replace _merge = 1 if idusing == 9009
replace _merge = 1 if idusing == 6107
replace _merge = 1 if idusing == 25279
replace _merge = 1 if idusing == 14427
replace _merge = 1 if idusing == 14569
replace _merge = 1 if idusing == 20776
replace _merge = 1 if idusing == 16757
replace _merge = 1 if idusing == 3862
replace _merge = 1 if idusing == 22088
replace _merge = 1 if idusing == 18475
replace _merge = 1 if idusing == 8844
replace _merge = 1 if idusing == 20738
replace _merge = 1 if idusing == 300
replace _merge = 1 if idusing == 5453
replace _merge = 1 if idusing == 8174
replace _merge = 1 if idusing == 16238
replace _merge = 1 if idusing == 14823
replace _merge = 1 if idusing == 12729
replace _merge = 1 if idusing == 23170
replace _merge = 1 if idusing == 7839
replace _merge = 1 if idusing == 5848
replace _merge = 1 if idusing == 15666
replace _merge = 1 if idusing == 17457
replace _merge = 1 if idusing == 20073
replace _merge = 1 if idusing == 12828
replace _merge = 1 if idusing == 10739
replace _merge = 1 if idusing == 1815
replace _merge = 1 if idusing == 13530
replace _merge = 1 if idusing == 12653
replace _merge = 1 if idusing == 5171
replace _merge = 1 if idusing == 19532
replace _merge = 1 if idusing == 17375
replace _merge = 1 if idusing == 25720
replace _merge = 1 if idusing == 13001
replace _merge = 1 if idusing == 18271
replace _merge = 1 if idusing == 16860
replace _merge = 1 if idusing == 14085
replace _merge = 1 if idusing == 1433
replace _merge = 1 if idusing == 13774
replace _merge = 1 if idusing == 22854
replace _merge = 1 if idusing == 19662
replace _merge = 1 if idusing == 8063
replace _merge = 1 if idusing == 6247
replace _merge = 1 if idusing == 4425
replace _merge = 1 if idusing == 19916
replace _merge = 1 if idusing == 8597
replace _merge = 1 if idusing == 24438
replace _merge = 1 if idusing == 7871
replace _merge = 1 if idusing == 20751
replace _merge = 1 if idusing == 21454
replace _merge = 1 if idusing == 1026
replace _merge = 1 if idusing == 13819
replace _merge = 1 if idusing == 10191
replace _merge = 1 if idusing == 531
replace _merge = 1 if idusing == 12417
replace _merge = 1 if idusing == 9178
replace _merge = 1 if idusing == 6314
replace _merge = 1 if idusing == 26220
replace _merge = 1 if idusing == 20201
replace _merge = 1 if idusing == 26471
replace _merge = 1 if idusing == 22853
replace _merge = 1 if idusing == 15765
replace _merge = 1 if idusing == 10307
replace _merge = 1 if idusing == 8086
replace _merge = 1 if idusing == 18879
replace _merge = 1 if idusing == 6475
replace _merge = 1 if idusing == 14451
replace _merge = 1 if idusing == 2867
replace _merge = 1 if idusing == 23455
replace _merge = 1 if idusing == 20383
replace _merge = 1 if idusing == 25564
replace _merge = 1 if idusing == 21829
replace _merge = 1 if idusing == 10810
replace _merge = 1 if idusing == 23977
replace _merge = 1 if idusing == 23484
replace _merge = 1 if idusing == 13369
replace _merge = 1 if idusing == 10537
replace _merge = 1 if idusing == 7576
replace _merge = 1 if idusing == 23822
replace _merge = 1 if idusing == 3210
replace _merge = 1 if idusing == 1125
replace _merge = 1 if idusing == 21058
replace _merge = 1 if idusing == 5713
replace _merge = 1 if idusing == 21061
replace _merge = 1 if idusing == 24677
replace _merge = 1 if idusing == 21581
replace _merge = 1 if idusing == 21179
replace _merge = 1 if idusing == 4689

replace _merge = 1 if myscore < 0.8846

replace _merge = 3 if idusing == 19073
replace _merge = 3 if idusing == 2625
replace _merge = 3 if idusing == 26253
replace _merge = 3 if idusing == 15138
replace _merge = 3 if idusing == 12621
replace _merge = 3 if idusing == 16251
replace _merge = 3 if idusing == 24257
replace _merge = 3 if idusing == 3218
replace _merge = 3 if idusing == 18403
replace _merge = 3 if idusing == 3241
replace _merge = 3 if idusing == 12919
replace _merge = 3 if idusing == 22154
replace _merge = 3 if idusing == 12158
replace _merge = 3 if idusing == 3178
replace _merge = 3 if idusing == 777
replace _merge = 3 if idusing == 24926
replace _merge = 3 if idusing == 14856
replace _merge = 3 if idusing == 1627
replace _merge = 3 if idusing == 11325
replace _merge = 3 if idusing == 13547
replace _merge = 3 if idusing == 22892
replace _merge = 3 if idusing == 20276
replace _merge = 3 if idusing == 16815
replace _merge = 3 if idusing == 9099
replace _merge = 3 if idusing == 10622
replace _merge = 3 if idusing == 3330
replace _merge = 3 if idusing == 16273
replace _merge = 3 if idusing == 11435
replace _merge = 3 if idusing == 13363
replace _merge = 3 if idusing == 11437
replace _merge = 3 if idusing == 11931
replace _merge = 3 if idusing == 18463
replace _merge = 3 if idusing == 14620
replace _merge = 3 if idusing == 22633
replace _merge = 3 if idusing == 13880
replace _merge = 3 if idusing == 236
replace _merge = 3 if idusing == 8688
replace _merge = 3 if idusing == 20713
replace _merge = 3 if idusing == 13546
replace _merge = 3 if idusing == 11504
replace _merge = 3 if idusing == 25890
replace _merge = 3 if idusing == 22545
replace _merge = 3 if idusing == 20263
replace _merge = 3 if idusing == 3573
replace _merge = 3 if idusing == 13091
replace _merge = 3 if idusing == 14664
replace _merge = 3 if idusing == 21792
replace _merge = 3 if idusing == 22325
replace _merge = 3 if idusing == 23567
replace _merge = 3 if idusing == 11139
replace _merge = 3 if idusing == 3679
replace _merge = 3 if idusing == 3571
replace _merge = 3 if idusing == 17835
replace _merge = 3 if idusing == 8403
replace _merge = 3 if idusing == 5609
replace _merge = 3 if idusing == 17667
replace _merge = 3 if idusing == 2073
replace _merge = 3 if idusing == 24424
replace _merge = 3 if idusing == 22728
replace _merge = 3 if idusing == 18926
replace _merge = 3 if idusing == 6022
replace _merge = 3 if idusing == 22645
replace _merge = 3 if idusing == 6087
replace _merge = 3 if idusing == 2652
replace _merge = 3 if idusing == 23607
replace _merge = 3 if idusing == 19359
replace _merge = 3 if idusing == 8829
replace _merge = 3 if idusing == 2575
replace _merge = 3 if idusing == 3768
replace _merge = 3 if idusing == 23367
replace _merge = 3 if idusing == 22985
replace _merge = 3 if idusing == 6262
replace _merge = 3 if idusing == 12281
replace _merge = 3 if idusing == 19174
replace _merge = 3 if idusing == 11626
replace _merge = 3 if idusing == 23152
replace _merge = 3 if idusing == 10194
replace _merge = 3 if idusing == 10535
replace _merge = 3 if idusing == 746
replace _merge = 3 if idusing == 22817
replace _merge = 3 if idusing == 22661
replace _merge = 3 if idusing == 23133
replace _merge = 3 if idusing == 16304
replace _merge = 3 if idusing == 2662
replace _merge = 3 if idusing == 20534
replace _merge = 3 if idusing == 8655
replace _merge = 3 if idusing == 16400
replace _merge = 3 if idusing == 14934
replace _merge = 3 if idusing == 1488
replace _merge = 3 if idusing == 19645
replace _merge = 3 if idusing == 20935
replace _merge = 3 if idusing == 6456
replace _merge = 3 if idusing == 20535
replace _merge = 3 if idusing == 11256
replace _merge = 3 if idusing == 16302
replace _merge = 3 if idusing == 16400
replace _merge = 3 if idusing == 1487
replace _merge = 3 if idusing == 19644
replace _merge = 3 if idusing == 745
replace _merge = 3 if idusing == 14937
replace _merge = 3 if idusing == 9636
replace _merge = 3 if idusing == 16488
replace _merge = 3 if idusing == 4600
replace _merge = 3 if idusing == 5094
replace _merge = 3 if idusing == 20533
replace _merge = 3 if idusing == 8654
replace _merge = 3 if idusing == 16490
replace _merge = 3 if idusing == 22744
replace _merge = 3 if idusing == 3860
replace _merge = 3 if idusing == 2661
replace _merge = 3 if idusing == 20690
replace _merge = 3 if idusing == 8197
replace _merge = 3 if idusing == 8656
replace _merge = 3 if idusing == 4087
replace _merge = 3 if idusing == 22665
replace _merge = 3 if idusing == 13585
replace _merge = 3 if idusing == 5257
replace _merge = 3 if idusing == 10020
replace _merge = 3 if idusing == 1202
replace _merge = 3 if idusing == 13692
replace _merge = 3 if idusing == 23267
replace _merge = 3 if idusing == 14257
replace _merge = 3 if idusing == 22731
replace _merge = 3 if idusing == 16546
replace _merge = 3 if idusing == 17245
replace _merge = 3 if idusing == 2636
replace _merge = 3 if idusing == 22939
replace _merge = 3 if idusing == 1615
replace _merge = 3 if idusing == 25164
replace _merge = 3 if idusing == 18241
replace _merge = 3 if idusing == 22681
replace _merge = 3 if idusing == 15455
replace _merge = 3 if idusing == 25420
replace _merge = 3 if idusing == 891
replace _merge = 3 if idusing == 12537
replace _merge = 3 if idusing == 14833
replace _merge = 3 if idusing == 19981
replace _merge = 3 if idusing == 20242
replace _merge = 3 if idusing == 4197
replace _merge = 3 if idusing == 25109
replace _merge = 3 if idusing == 9839
replace _merge = 3 if idusing == 19398
replace _merge = 3 if idusing == 14605
replace _merge = 3 if idusing == 5900
replace _merge = 3 if idusing == 9873
replace _merge = 3 if idusing == 12703
replace _merge = 3 if idusing == 20708
replace _merge = 3 if idusing == 15005
replace _merge = 3 if idusing == 9601
replace _merge = 3 if idusing == 12351
replace _merge = 3 if idusing == 11226
replace _merge = 3 if idusing == 6240
replace _merge = 3 if idusing == 10493
replace _merge = 3 if idusing == 11227
replace _merge = 3 if idusing == 25438
replace _merge = 3 if idusing == 10550
replace _merge = 3 if idusing == 11324
replace _merge = 3 if idusing == 11827
replace _merge = 3 if idusing == 15337
replace _merge = 3 if idusing == 22544
replace _merge = 3 if idusing == 7186
replace _merge = 3 if idusing == 13095
replace _merge = 3 if idusing == 15418
replace _merge = 3 if idusing == 25562
replace _merge = 3 if idusing == 11379
replace _merge = 3 if idusing == 11930
replace _merge = 3 if idusing == 10221
replace _merge = 3 if idusing == 24970
replace _merge = 3 if idusing == 16936
replace _merge = 3 if idusing == 3081
replace _merge = 3 if idusing == 15467
replace _merge = 3 if idusing == 11041
replace _merge = 3 if idusing == 4720
replace _merge = 3 if idusing == 18087
replace _merge = 3 if idusing == 1616
replace _merge = 3 if idusing == 4981
replace _merge = 3 if idusing == 2174
replace _merge = 3 if idusing == 25954
replace _merge = 3 if idusing == 23994
replace _merge = 3 if idusing == 11661
replace _merge = 3 if idusing == 9474
replace _merge = 3 if idusing == 7584
replace _merge = 3 if idusing == 24871
replace _merge = 3 if idusing == 15420
replace _merge = 3 if idusing == 26275
replace _merge = 3 if idusing == 26317
replace _merge = 3 if idusing == 2037
replace _merge = 3 if idusing == 2754
replace _merge = 3 if idusing == 10171
replace _merge = 3 if idusing == 19542
replace _merge = 3 if idusing == 4886
replace _merge = 3 if idusing == 151
replace _merge = 3 if idusing == 22534
replace _merge = 3 if idusing == 12695
replace _merge = 3 if idusing == 23595
replace _merge = 3 if idusing == 25998
replace _merge = 3 if idusing == 25862
replace _merge = 3 if idusing == 7962
replace _merge = 3 if idusing == 25274
replace _merge = 3 if idusing == 24542
replace _merge = 3 if idusing == 21122
replace _merge = 3 if idusing == 2178
replace _merge = 3 if idusing == 13017
replace _merge = 3 if idusing == 6763
replace _merge = 3 if idusing == 16200
replace _merge = 3 if idusing == 25275
replace _merge = 3 if idusing == 23817
replace _merge = 3 if idusing == 25969
replace _merge = 3 if idusing == 14044
replace _merge = 3 if idusing == 6331
replace _merge = 3 if idusing == 23920
replace _merge = 3 if idusing == 6762
replace _merge = 3 if idusing == 13078
replace _merge = 3 if idusing == 13010
replace _merge = 3 if idusing == 23818
replace _merge = 3 if idusing == 22787
replace _merge = 3 if idusing == 16733
replace _merge = 3 if idusing == 13009
replace _merge = 3 if idusing == 149
replace _merge = 3 if idusing == 1259

rename _merge status

merge m:1 idmaster using "$datapath\w4_nwdesk.dta", keep(match master)

gen test = 1 if status == 3 & net13p_w4 == 97

tab test

sort test 

replace status = 1 if test == 1  

save "$datapath\aftermatch.dta", replace

keep if status == 3

duplicates list idusing

duplicates drop idusing, force

save "$datapath\matches.dta", replace


*********************
*** Out-Selection ***
********************* 

use "$datapath\anchor4.dta", clear

gen id_w4 = id 

replace id_w4 = id_w4 / 1000
replace id = id / 1000

keep id id_w4

save "$datapath\idw4.dta", replace

use "$datapath\anchor2.dta", clear

replace id = id / 1000

keep id relstat k1age-k10age sex_gen age pregnant infertile k1type-k10type nkids nkidsbio ykage ykagecapi

save "$datapath\out_anchor2.dta", replace

use "$datapath\link2.dta", clear

merge 1:1 idusing using "matches.dta", keep(match master) keepusing(status)

drop _merge

merge m:1 id using "idw4.dta", keep(match master)

drop _merge

merge m:1 id using "out_anchor2.dta", keep (match master)

save "$datapath\outselection.dta", replace

keep if id_w4 < .

* DV: nw person stays in nw (1) or selects outs (0) 

replace status = 0 if status == .
recode status (3=1)

drop if net5p == 1

* Type of network person: friend (1), sibling (2) or other kin(3)

gen type = 1 if net5p == 21 | net5p == 2 

replace type = 2 if net5p == 12

replace type = 3 if net5p == 15 | net5p == 17 | net5p == 19 | net5p == 20 

gen filter_out = 0 

replace filter_out = 1 if net5p == 21 | net5p == 2 | net5p == 12 | net5p == 15 ///
| net5p == 17 | net5p == 19 | net5p == 20

* Closeness to nwp

rename net7p close

* Age of nwp (7-17 years, 17-22, 23-27, 28-32, 33-37, 37-42, 43-99)

recode net10p (1/2=1)(2=2) (3=3) (4=4) (5=5) (6=6) (7/13=7), gen(nwpage)

* Sex of nwp and sex homogamy 

recode net11p (1=1) (2=0), gen(nwp_male)

gen sexhom = 0 
replace sexhom = 1 if (sex_gen == 1 & nwp_male == 1) | (sex_gen == 2 & nwp_male == 0)

* Nwp has children < 3 years 

recode net12p (-3=.) (0=0) (1/5=1), gen(nwp_child) 

* Relationship duration anchor-nwp 

recode net13p (-3=.) (97=0.5), gen(reldur)

* Sex of anchor 

recode sex_gen (1=1) (2=0) (-4=.), gen(male)

* Age of anchor (age) and age difference 

gen agediff = age - net10p_copy 
replace agediff= agediff*-1 if agediff < 0

* Family status of anchor 

gen childless = 1 
replace childless = 0 if nkids > 0 | pregnant == 1

recode k1age (0/2=1) (3/7=2) (8/99=3), gen(agek1) 
recode k2age (0/2=1) (3/7=2) (8/99=3), gen(agek2)  
recode k3age (0/2=1) (3/7=2) (8/99=3), gen(agek3) 
recode k4age (0/2=1) (3/7=2) (8/99=3), gen(agek4) 
recode k5age (0/2=1) (3/7=2) (8/99=3), gen(agek5) 
recode k6age (0/2=1) (3/7=2) (8/99=3), gen(agek6) 
recode k7age (0/2=1) (3/7=2) (8/99=3), gen(agek7) 
recode k8age (0/2=1) (3/7=2) (8/99=3), gen(agek8) 
recode k9age (0/2=1) (3/7=2) (8/99=3), gen(agek9) 
recode k10age (0/2=1) (3/7=2) (8/99=3), gen(agek10)

egen child02 = anycount(agek1-agek10), values(1)
egen child37 = anycount(agek1-agek10), values(2)
egen child8p = anycount(agek1-agek10), values(3)

recode child02 (0=0) (1/99=1)
recode child37 (0=0) (1/99=1)
recode child8p (0=0) (1/99=1) 

gen aycw2 = 0 
replace aycw2 = 1 if (ykage > -3 & ykage < 37) | (ykagecapi > -3 & ykagecapi < 37) 

gen akgcw2 = 0 
replace akgcw2 = 1 if (ykage > -3 & ykage > 36 & ykage < 85) | (ykagecapi > -3 & ykagecapi > 36 & ykagecapi < 85)

gen aocw2 = 0 
replace aocw2 = 1 if (ykage > -3 & ykage > 84) | (ykagecapi > -3 & ykagecapi > 84)

* replace child02 = 1 if pregnant == 1

gen famstat = 1 if childless == 1 
replace famstat = 2 if child02 == 1 
replace famstat = 3 if child37 == 1
replace famstat = 4 if child8p == 1

sum status type close nwpage nwp_male nwp_child reldur male age famstat

recode net14p (2=1) (3=1) (1=0) (4=0) (5=0) (-3=.), gen(nwp_marr)

* Merge 

drop _merge

merge m:1 id using "intdate_w2.dta", keep(match master)

drop _merge 

merge m:1 id using "lambdaid_w2.dta", keep(match master)

drop _merge 

merge m:1 id using "intid_w4.dta", keep(match master)

tab type, gen(nwtype)
rename nwtype1 friend 
rename nwtype2 sibling
rename nwtype3 otherkin

recode pregnant (-7=0) (-3=0)

keep id age sex_gen marr pregnant child02 child37 child8p friend sibling otherkin agediff ///
sexhom reldur nwp_marr nwp_child close lambda nwsize_w2_all status net5p net10p_copy

save "$datapath\outselect_extend.dta", replace


********************
*** Selecting in ***
********************

use "$datapath\matches.dta", clear

duplicates drop idmaster, force

save "$datapath\matches2.dta", replace

use "$datapath\link4.dta", clear

merge 1:1 idmaster using "matches2.dta", keep(match master) keepusing(status)

drop _merge

merge m:1 id using "out_anchor4.dta", keep (match master)

save "$datapath\inselection.dta", replace

* Age homogamy (at W2)

gen nwp_agew2 = net10p_copy - intdiff 

gen agediff = age - nwp_agew2 
replace agediff = agediff * -1 if agediff < 0

* Sex of nwp and sex homogamy 

recode sex_gen (1=1) (else=0), gen(male)

recode net11p (1=1) (2=0), gen(nwp_male)

gen sexhom = 0 
replace sexhom = 1 if (sex_gen == 1 & nwp_male == 1) | (sex_gen == 2 & nwp_male == 0)

* Type of network person 

gen type = 1 if net5p == 21 | net5p == 2 

replace type = 2 if net5p == 12

replace type = 3 if net5p == 15 | net5p == 17 | net5p == 19 | net5p == 20 

gen filter_in = 0 

replace filter_in = 1 if net5p == 21 | net5p == 2 | net5p == 12 | net5p == 15 ///
| net5p == 17 | net5p == 19 | net5p == 20

tab type, gen(nwtype)
rename nwtype1 friend 
rename nwtype2 sibling
rename nwtype3 otherkin

* Family status anchor W2 

recode k1age (0/2=1) (3/7=2) (8/99=3), gen(agek1) 
recode k2age (0/2=1) (3/7=2) (8/99=3), gen(agek2)  
recode k3age (0/2=1) (3/7=2) (8/99=3), gen(agek3) 
recode k4age (0/2=1) (3/7=2) (8/99=3), gen(agek4) 
recode k5age (0/2=1) (3/7=2) (8/99=3), gen(agek5) 
recode k6age (0/2=1) (3/7=2) (8/99=3), gen(agek6) 
recode k7age (0/2=1) (3/7=2) (8/99=3), gen(agek7) 
recode k8age (0/2=1) (3/7=2) (8/99=3), gen(agek8) 
recode k9age (0/2=1) (3/7=2) (8/99=3), gen(agek9) 
recode k10age (0/2=1) (3/7=2) (8/99=3), gen(agek10)

egen child02 = anycount(agek1-agek10), values(1)
egen child37 = anycount(agek1-agek10), values(2)
egen child8p = anycount(agek1-agek10), values(3)

recode child02 (0=0) (1/99=1)
recode child37 (0=0) (1/99=1)
recode child8p (0=0) (1/99=1) 

recode relstat (1=1) (6=1) (9=1) (-7=.) (else=0), gen(single) 
recode relstat (2=1) (5=1) (7=1) (-7=.) (else=0), gen(lat)
recode relstat (3=1) (8=1) (-7=.) (else=0), gen(nel) 
recode relstat (4=1) (-7=.) (else=0), gen(marr) 

recode pregnant (-7=0) (-3=0)

gen nwp_marr = 0 
replace nwp_marr = 1 if net14p == 2 | net14p == 3

* Merge 

drop _merge

merge m:1 id using "intdate_w2.dta", keep(match master)

drop _merge 

merge m:1 id using "lambdaid_w2.dta", keep(match master)

drop _merge 

merge m:1 id using "intid_w4.dta", keep(match master)

rename net7p close

recode net13p (-3=.) (97=0.5), gen(reldur)

recode net12p (-3=.) (0=0) (1/5=1), gen(nwp_child) 

drop if status == 3

replace status = 2

keep id age sex_gen marr pregnant child02 child37 child8p friend sibling otherkin agediff ///
sexhom reldur nwp_marr nwp_child close lambda nwsize_w2_all status net5p net10p_copy

save "$datapath\inselection_extend.dta", replace


**************
*** Append ***
************** 

append using "$datapath\outselect_extend.dta"

* Imputation (agediff, marr, nwp_marr, nwp_child, reldur, sibling, friend, lambda size)

recode sex_gen (-4=.)
drop if sex_gen == .

recode sex_gen (1=1) (2=0), gen(male)

recode nwp_child (-5=.) (6=1)

replace reldur = age if sibling == 1

rename nwsize_w2_all size

impute agediff male sexhom age close pregnant child02 child37 child8p marr, gen(agediff2)

impute nwp_marr agediff2 male sexhom age close pregnant child02 child37 child8p marr, gen(nwp_marr2)

impute nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(nwp_child2)

impute reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(reldur2)

impute friend reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(friend2)

impute sibling reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(sibling2)

impute marr sibling reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(marr2)

impute lambda marr sibling reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(lambda2)

impute size marr sibling reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(size2)

impute close size marr sibling reldur nwp_child agediff2 male sexhom age close pregnant child02 child37 child8p marr nwp_marr2, gen(close2)

sum agediff agediff2 nwp_marr2 nwp_child2 reldur reldur2 

recode nwp_marr2 sibling2 friend2 marr2 (-5/0.4999=0) (0.5/1.5=1)

recode nwp_child2 (-5/0.49999=0) (0.5/1.5=1)

replace friend = 0 if sibling == 1 
replace sibling = 0 if friend == 1

recode reldur2 (-10/0.5=0.5)
recode size2 (-10/0=0)


**************
*** Models ***
**************

* Fertility status: interactions  

gen both_sk = child02*nwp_child2 

gen pregxsk = pregnant*nwp_child2 

gen k37xsk = child37*nwp_child2 

gen k8xsk = child8p*nwp_child2 

* Models

gen agez = age - 25.2 
gen ageq = agez*agez

gen reldurz = reldur2 - 9.5
gen reldurq = reldurz*reldurz

gen marrhom = 0 
replace marrhom = 1 if nwp_marr2 == 1 & marr2 == 1

xtset id

* Table A1

sum status age agez ageq marr2 friend2 sibling2 agediff2 reldur2 reldurz reldurq marrhom sexhom  ///
pregnant child02 child37 child8p nwp_child2 both_sk pregxsk k37xsk k8xsk lambda2 size2 close2 if male == 1

sum status age agez ageq marr2 friend2 sibling2 agediff2 reldur2 reldurz reldurq marrhom sexhom  ///
pregnant child02 child37 child8p nwp_child2 both_sk pregxsk k37xsk k8xsk lambda2 size2 close2 if male == 0

* RE models, Table 1 

gen agez2= agez/100
gen ageq2 = ageq/100

gen reldurz2 = reldurz/100
gen reldurq2 = reldurq/100

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 lambda2 size2 close2 if male == 1, baseoutcome(0) re

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 lambda2 size2 close2 if male == 0, baseoutcome(0) re

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
c.child02##male c.child37##male c.child8p##male c.nwp_child2##male lambda2 size2 close2, baseoutcome(0) re

* FE and RE Models, Table 2 

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 1, baseoutcome(0) re

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 0, baseoutcome(0) re

xtmlogit status agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
c.child02##male nwp_child2##male c.child02##nwp_child2 c.child02##nwp_child2##male lambda2 size2 close2 ///
c.child37##male nwp_child2##male c.child37##nwp_child2 c.child37##nwp_child2##male ///
c.child8p##male nwp_child2##male c.child8p##nwp_child2 c.child8p##nwp_child2##male, baseoutcome(0) re


xtmlogit status reldurz2 reldurq2 agediff2 sexhom marrhom friend2 sibling2 close2 nwp_child2 both_sk ///
k37xsk k8xsk if male == 0, baseoutcome(0) fe

xtmlogit status reldurz2 reldurq2 agediff2 sexhom marrhom friend2 sibling2 close2 nwp_child2 both_sk ///
k37xsk k8xsk if male == 1, baseoutcome(0) fe

xtmlogit status reldurz2 reldurq2 agediff2 sexhom marrhom friend2 sibling2 close2  ///
c.child02##male nwp_child2##male c.child02##nwp_child2 c.child02##nwp_child2##male, baseoutcome(0) fe

xtmlogit status reldurz2 reldurq2 agediff2 sexhom marrhom friend2 sibling2 close2  ///
c.child37##male nwp_child2##male c.child37##nwp_child2 c.child37##nwp_child2##male, baseoutcome(0) fe

xtmlogit status reldurz2 reldurq2 agediff2 sexhom marrhom friend2 sibling2 close2 ///
c.child8p##male nwp_child2##male c.child8p##nwp_child2 c.child8p##nwp_child2##male, baseoutcome(0) fe

* Hausman (estimated separated by outcomes using xtlogit and only related to main effects of children 
* and interaction effects)

gen a1 = 0 if status == 0 
replace a1 = 1 if status == 1 

gen a2 = 0 if status == 0 
replace a2 = 1 if status == 2

* transition maintained vs. discontinued

eststo re1: xtlogit a1 agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 1, re

eststo fe1: xtlogit a1 nwp_child2 both_sk k37xsk k8xsk if male == 1, fe

hausman re1 fe1

eststo re2: xtlogit a1 agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz2 reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 0, re

eststo fe2: xtlogit a1 nwp_child2 both_sk k37xsk k8xsk if male == 0, fe

hausman re2 fe2 

eststo re3: xtlogit a2 agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 1, re

eststo fe3: xtlogit a2 nwp_child2 both_sk k37xsk k8xsk if male == 1, fe

hausman re3 fe3 

eststo re4: xtlogit a2 agez2 ageq2 marr2 friend2 sibling2 agediff2 reldurz reldurq2 marrhom sexhom ///
child02 child37 child8p nwp_child2 both_sk k37xsk k8xsk lambda2 size2 close2 if male == 0, re

eststo fe4: xtlogit a2 nwp_child2 both_sk k37xsk k8xsk if male == 0, fe

hausman re4 fe4 

* Figure 2
recode a1 (1=0) (0=1), gen(disc_stab)

xtlogit disc_stab c.age##c.age marr2 friend2 sibling2 agediff2 c.reldur2##c.reldur2 marrhom sexhom ///
c.child02##nwp_child2 c.child37##nwp_child2 c.child8p##nwp_child2 lambda2 size2 close2 if male == 0, re

margins, at(nwp_child2=(0 1) child02=(0 1) child37=(0 1) child8p=(0 1))

xtlogit disc_stab c.age##c.age marr2 friend2 sibling2 agediff2 c.reldur2##c.reldur2 marrhom sexhom ///
c.child02##nwp_child2 c.child37##nwp_child2 c.child8p##nwp_child2 lambda2 size2 close2 if male == 1, re

margins, at(nwp_child2=(0 1) child02=(0 1) child37=(0 1) child8p=(0 1))

* Figure 3
xtlogit a2 c.age##c.age marr2 friend2 sibling2 agediff2 c.reldur2##c.reldur2 marrhom sexhom ///
c.child02##nwp_child2 c.child37##nwp_child2 c.child8p##nwp_child2 lambda2 size2 close2 if male == 0, re

margins, at(nwp_child2=(0 1) child02=(0 1) child37=(0 1) child8p=(0 1))

xtlogit a2 c.age##c.age marr2 friend2 sibling2 agediff2 c.reldur2##c.reldur2 marrhom sexhom ///
c.child02##nwp_child2 c.child37##nwp_child2 c.child8p##nwp_child2 lambda2 size2 close2 if male == 1, re

margins, at(nwp_child2=(0 1) child02=(0 1) child37=(0 1) child8p=(0 1))









